@@ -89,6 +89,8 @@ class Colab:
                 nb_config["graphics"]["cores"] = [1, -1, -1]
                 nb_config["graphics"]["boardType"] = resource.gpu.value
 
+            nb_config["graphics"]["memoryPerCard"] = resource.memory_per_card
+
         # Plug in requirements
         if notifications != None:
             nb_config["notifications"] = {
@@ -142,16 +144,16 @@ class Colab:
         creation_times = [
             datetime.datetime.utcfromtimestamp(stat.st_ctime).isoformat() + "Z"
             if stat != None
-            else str(None)
+            else None
             for stat in stats
         ]
         last_modification_times = [
             datetime.datetime.utcfromtimestamp(stat.st_mtime).isoformat() + "Z"
             if stat != None
-            else str(None)
+            else None
             for stat in stats
         ]
-        sizes = [str(stat.st_size) if stat else str(None) for stat in stats]
+        sizes = [str(stat.st_size) if stat else None for stat in stats]
 
         optumi.core.launch_notebook(
             nb_config["upload"]["requirements"],
