@@ -105,6 +105,8 @@ class Executable:
                 nb_config["graphics"]["cores"] = [1, -1, -1]
                 nb_config["graphics"]["boardType"] = resource.gpu.value
 
+            nb_config["graphics"]["memoryPerCard"] = resource.memory_per_card
+
         # Plug in requirements
         if notifications != None:
             nb_config["notifications"] = {
@@ -121,7 +123,10 @@ class Executable:
             optumi.core.setup_notebook(
                 optumi.utils.replace_home_with_tilde(self._path),
                 self.__utcnow(),
-                {"path": optumi.utils.replace_home_with_tilde(self._path), "content": program},
+                {
+                    "path": optumi.utils.replace_home_with_tilde(self._path),
+                    "content": program,
+                },
                 json.dumps(nb_config),
             ).text
         )
@@ -140,16 +145,16 @@ class Executable:
         creation_times = [
             datetime.datetime.utcfromtimestamp(stat.st_ctime).isoformat() + "Z"
             if stat != None
-            else str(None)
+            else None
             for stat in stats
         ]
         last_modification_times = [
             datetime.datetime.utcfromtimestamp(stat.st_mtime).isoformat() + "Z"
             if stat != None
-            else str(None)
+            else None
             for stat in stats
         ]
-        sizes = [str(stat.st_size) if stat else str(None) for stat in stats]
+        sizes = [str(stat.st_size) if stat else None for stat in stats]
 
         try:
             optumi.core.launch_notebook(
@@ -175,7 +180,12 @@ class Executable:
         )
 
         workload = Workload(
-            optumi.utils.replace_home_with_tilde(self._path), program, workload_uuid, module_uuid, nb_config, run_num
+            optumi.utils.replace_home_with_tilde(self._path),
+            program,
+            workload_uuid,
+            module_uuid,
+            nb_config,
+            run_num,
         )
         if wait:
             workload.wait(progress)
