@@ -8,6 +8,8 @@
 import os
 from .utils import *
 
+import optumi_core as optumi
+
 
 class Log:
     def __init__(self, name: str, output: list):
@@ -15,10 +17,8 @@ class Log:
         self._output = output
 
     def download(self, path: str = None):
-        f_name = os.path.abspath(
-            os.path.expanduser(
-                self._name.split("/")[-1] + ".log" if path is None else path
-            )
+        f_name = optumi.utils.normalize_path(
+            self._name.split("/")[-1] + ".log" if path is None else path
         )
         with open(f_name, "w+") as f:
             f.write(
