@@ -7,6 +7,8 @@
 
 import os
 
+import optumi_core as optumi
+
 
 class Program:
     def __init__(self, name: str, run_num: str, program: str):
@@ -16,14 +18,12 @@ class Program:
 
     def download(self, path: str = None):
         extension = "." + self._name.split(".")[-1]
-        f_name = os.path.abspath(
-            os.path.expanduser(
-                self._name.split("/")[-1].replace(
-                    extension, "-" + str(self._run_num) + extension
-                )
-                if path is None
-                else path
+        f_name = optumi.utils.normalize_path(
+            self._name.split("/")[-1].replace(
+                extension, "-" + str(self._run_num) + extension
             )
+            if path is None
+            else path
         )
         with open(f_name, "w+") as f:
             f.write(self._program)
