@@ -17,15 +17,21 @@ class GpuType(Enum):
     NVIDIA_P40 = "P40"
     NVIDIA_V100 = "V100"
     NVIDIA_T4 = "T4"
+    NVIDIA_A100 = "A100"
 
 
 class Resource:
-    def __init__(self, gpu: Union[bool, GpuType] = True):
+    def __init__(self, gpu: Union[bool, GpuType] = True, memory_per_card=0):
         self._gpu = gpu
+        self._memory_per_card = memory_per_card
 
     @property
     def gpu(self):
         return self._gpu
 
+    @property
+    def memory_per_card(self):
+        return self._memory_per_card
+
     def __str__(self):
         return "gpu=" + str(self.gpu)
