@@ -8,6 +8,7 @@
 import optumi_core as optumi
 
 from .CloudStorage import CloudStorage
+from .CloudFile import CloudFile
 from .CloudFileVersion import CloudFileVersion
 from .Log import Log
 from .Summary import Summary
@@ -68,13 +69,13 @@ class Workload:
         self._initializing_lines = initializing_lines.copy()
         self._preparing_lines = preparing_lines.copy()
         self._running_lines = running_lines.copy()
-        self._input_files = []
+        self._input_files = CloudStorage(input_files.copy())
 
         self._update_lines = update_lines.copy()
         self._output = output.copy()
         self._last_patches = num_patches
 
-        self._output_files = output_files.copy()
+        self._output_files = CloudStorage(output_files.copy())
 
         self._machine = machine
         self._token = token
@@ -98,24 +99,30 @@ class Workload:
         for i in range(len(app_map["running"])):
             running.append((app_map["running"][i], app_map["runningmod"][i]))
 
-        input_files = []
-        if "files" in app_map:
-            for i in range(len(app_map["files"])):
-                if app_map["files"][i] != "":
-                    input_files.append(
-                        CloudFileVersion(
-                            app_map["files"][i],
-                            app_map["hashes"][i],
-                            int(app_map["filessize"][i]),
-                            app_map["filescrt"][i],
-                            app_map["filesmod"][i],
-                        )
+        input_files = CloudStorage([])
+        if "files" in app_map and app_map["files"] != None:
+            input_files = CloudStorage(
+                [
+                    CloudFile(
+                        app_map["files"][i],
+                        [
+                            CloudFileVersion(
+                                app_map["files"][i],
+                                app_map["hashes"][i],
+                                int(app_map["filessize"][i]),
+                                app_map["filescrt"][i],
+                                app_map["filesmod"][i],
+                            )
+                        ],
                     )
+                    for i in range(len(app_map["files"]))
+                ]
+            )
 
         module_uuid = None
         output = []
         updates = []
-        output_files = []
+        output_files = CloudStorage([])
         num_patches = 0
         program = None
         machine = None
@@ -134,17 +141,23 @@ class Workload:
                     updates.append((module["updates"][i], module["updatesmod"][i]))
 
             if "files" in module:
-                for i in range(len(module["files"])):
-                    if module["files"][i] != "":
-                        output_files.append(
-                            CloudFileVersion(
-                                module["files"][i],
-                                module["hashes"][i],
-                                int(module["filessize"][i]),
-                                module["filescrt"][i],
-                                module["filesmod"][i],
-                            )
+                output_files = CloudStorage(
+                    [
+                        CloudFile(
+                            module["files"][i],
+                            [
+                                CloudFileVersion(
+                                    module["files"][i],
+                                    module["hashes"][i],
+                                    int(module["filessize"][i]),
+                                    module["filescrt"][i],
+                                    module["filesmod"][i],
+                                )
+                            ],
                         )
+                        for i in range(len(module["files"]))
+                    ]
+                )
 
             # monitoring = []
             # if 'monitoring' in module:
@@ -319,12 +332,17 @@ class Workload:
 
                 self._output_files = CloudStorage(
                     [
-                        CloudFileVersion(
+                        CloudFile(
                             updates["files"][i],
-                            updates["hashes"][i],
-                            int(updates["filessize"][i]),
-                            updates["filescrt"][i],
-                            updates["filesmod"][i],
+                            [
+                                CloudFileVersion(
+                                    updates["files"][i],
+                                    updates["hashes"][i],
+                                    int(updates["filessize"][i]),
+                                    updates["filescrt"][i],
+                                    updates["filesmod"][i],
+                                )
+                            ],
                         )
                         for i in range(len(updates["files"]))
                     ]
