@@ -128,11 +128,8 @@ def set_phone_number(phone_number):
             if text:
                 print(text)
                 # This is kind of sketchy but wont break if the message changes, it will just continue prompting the user for their code
-                if text == 'Max check attempts reached':
+                if text == "Max check attempts reached":
                     break
             else:
                 optumi.set_user_information("notificationsEnabled", True)
                 break
-
-
-        
\ No newline at end of file
